@@ -1,6 +1,7 @@
-from .mappers import get_default_mapper
 from django.utils.text import slugify
 
+from .mappers import get_default_mapper
+
 
 class ContentImportMixin:
     """
@@ -16,8 +17,12 @@ class ContentImportMixin:
         """
         Factory method to create the Page and populate it from a parsed document.
         """
-        title = parsed_doc["title"]
-        mapper_class = cls.mapper_class
-        mapper = mapper_class()
-        imported_data = mapper.map(parsed_doc["elements"], user=user)
-        return cls(title=title, slug=slugify(title), body=imported_data, owner=user,)
+        page = cls(owner=user)
+        page.update_from_import(parsed_doc, user)
+        return page
+
+    def update_from_import(self, parsed_doc, user):
+        self.title = parsed_doc["title"]
+        self.slug = slugify(self.title)
+        mapper = self.mapper_class()
+        self.body = mapper.map(parsed_doc["elements"], user=user)
