@@ -1,13 +1,11 @@
-import requests
-
 from io import BytesIO
 
+import requests
 from django.conf import settings
-
 from wagtail.core import hooks
 
+from ...utils import create_page_from_import, update_page_from_import
 from .utils import MicrosoftPicker, parse_document
-from ...utils import create_page_from_import
 
 
 @hooks.register("register_content_import_picker")
@@ -25,3 +23,13 @@ def create_from_microsoft_doc(request, parent_page, page_class):
         if response.status_code == 200:
             parsed_doc = parse_document(BytesIO(response.content))
             return create_page_from_import(request, parent_page, page_class, parsed_doc)
+
+
+@hooks.register("before_edit_page")
+def edit_from_microsoft_doc(request, page):
+    if "microsoft-doc" in request.POST:
+        document_url = request.POST["microsoft-doc"]
+        response = requests.get(document_url)
+        if response.status_code == 200:
+            parsed_doc = parse_document(BytesIO(response.content))
+            return update_page_from_import(request, page, parsed_doc)
