@@ -1,6 +1,5 @@
 from django import template
 from django.utils.safestring import mark_safe
-
 from wagtail.core import hooks
 
 register = template.Library()
@@ -20,9 +19,21 @@ def wagtailcontentimport_pickerjs(context):
 
 
 @register.inclusion_tag(
-    "wagtail_content_import/picker_buttons.html", takes_context=True
+    "wagtail_content_import/picker_buttons_create.html", takes_context=True
 )
-def wagtailcontentimport_picker_buttons(context):
+def wagtailcontentimport_picker_buttons_create(context):
+    pickers = [fn() for fn in hooks.get_hooks("register_content_import_picker") if fn()]
+    if pickers:
+        context["default_picker"] = pickers[0]
+        if len(pickers) > 1:
+            context["picker_options"] = pickers[1:]
+    return context
+
+
+@register.inclusion_tag(
+    "wagtail_content_import/picker_buttons_edit.html", takes_context=True
+)
+def wagtailcontentimport_picker_buttons_edit(context):
     pickers = [fn() for fn in hooks.get_hooks("register_content_import_picker") if fn()]
     if pickers:
         context["default_picker"] = pickers[0]
